%
%   solve_step   (used several times within script file regblade_sim.m)
%
%   Note that this is a script file, not a function file.  This section of code was
%   repeated exactly for each step in the simulation sequence, and it works on the
%   data currently available in the work space.  Thus, to simply streamline the 
%   simulation, I decided to make this a separate script file and just call it for 
%   each step in the simulation sequence (with a new zlocs vector in the workspace 
%   each time).  In the original version, this code was simply repeated many times.  
%   Obviously, the current approach of a separate script file is more efficient from 
%   a visual (or file size) perspective, but not computationally -- since everything 
%   is essentially the same from a calculational view...
%
%   Written by JRWhite, UMass-Lowell (last update: March 2018)
%

      if zlocs(2) < zlocs(1), speed = -speed;  end
      dtt = (zlocs(2)-zlocs(1))/speed;  dtt = ceil(dtt)+thold;
      ts = 0:dt:dtt;  xo = x(end,:)';  rho0 = rhoend;
      ftx = @(t,x) pkeqns_rampb_nofdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu, ...
                                         rate,zlocs,boi,yr);
      [ts,x] = ode15s(ftx,ts,xo,options);
      tstrt = tend;  t = tstrt + ts;  tend = t(end);
      P = x(:,1);             
%   add some noise 
      rn = rand(size(ts));    % vector of uniform random numbers (0 to 1)
      srn = (b-a)*rn + a;     % uniformly distributed between a and b
      srn(1) = 1.0;           % reset initial value to 1.0
      Pn = srn.*P;            % P(t) with random noise
%   save data for subsequent processing
      z = zlocs(1)+speed*ts;  
      if speed > 0, z(z > zlocs(2)) = zlocs(2);  end
      if speed < 0, z(z < zlocs(2)) = zlocs(2);  end
      drho = bworth(z,boi,yr)-bworth(z(1),boi,yr);  drho = drho/100; % Dk/k
      rho = rho0+drho;  rhoend = rho(end);
      rr = [rr; rho];  tt = [tt; t];  PP = [PP; Pn];  zz = [zz; z];
%
%   end of script